#[repr(transparent)]pub struct TimeZoneVariantULE(u8);Expand description
ULE type for TimeZoneVariant
Tuple Fields
0: u8Trait Implementations
Sourceimpl Clone for TimeZoneVariantULE
impl Clone for TimeZoneVariantULE
Sourcefn clone(&self) -> TimeZoneVariantULE
fn clone(&self) -> TimeZoneVariantULE
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Ord for TimeZoneVariantULE
impl Ord for TimeZoneVariantULE
Sourcefn cmp(&self, other: &TimeZoneVariantULE) -> Ordering
fn cmp(&self, other: &TimeZoneVariantULE) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TimeZoneVariantULE
impl PartialEq for TimeZoneVariantULE
Sourcefn eq(&self, other: &TimeZoneVariantULE) -> bool
fn eq(&self, other: &TimeZoneVariantULE) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TimeZoneVariantULE
impl PartialOrd for TimeZoneVariantULE
Sourceimpl ULE for TimeZoneVariantULE
impl ULE for TimeZoneVariantULE
Sourcefn validate_bytes(bytes: &[u8]) -> Result<(), UleError>
fn validate_bytes(bytes: &[u8]) -> Result<(), UleError>
Validates a byte slice,
&[u8]. Read moreSourceunsafe fn slice_from_bytes_unchecked(bytes: &[u8]) -> &[Self]
unsafe fn slice_from_bytes_unchecked(bytes: &[u8]) -> &[Self]
Takes a byte slice,
&[u8], and return it as &[Self] with the same lifetime, assuming
that this byte slice has previously been run through Self::parse_bytes_to_slice() with
success. Read moreimpl Copy for TimeZoneVariantULE
impl Eq for TimeZoneVariantULE
impl StructuralPartialEq for TimeZoneVariantULE