pub struct TimezonePeriods<'a> {
pub index: ZeroTrieSimpleAscii<ZeroVec<'a, u8>>,
pub list: VarZeroVec<'a, VarTupleULE<(u8, NichedOption<MetazoneId, 1>), ZeroSlice<(Timestamp24, u8, NichedOption<MetazoneId, 1>)>>>,
pub offsets: ZeroVec<'a, VariantOffsetsWithMetazoneMembershipKind>,
}Expand description
Data struct for the TimezonePeriodsV1 marker.
Fields
index: ZeroTrieSimpleAscii<ZeroVec<'a, u8>>Index of TimeZones into list.
list: VarZeroVec<'a, VarTupleULE<(u8, NichedOption<MetazoneId, 1>), ZeroSlice<(Timestamp24, u8, NichedOption<MetazoneId, 1>)>>>Each entry contains at least one period, which implicitly starts at the UNIX epoch. This is stored in the first tuple element.
If more periods are required the second tuple element contains them, along with their starting timestamp. These entries are ordered chronologically.
The values ((u8, Option<MetazoneId>)) are an index into the offsets list for the offset
that the zone observes in that period, and optionally whether it is part of a metazone.
offsets: ZeroVec<'a, VariantOffsetsWithMetazoneMembershipKind>The deduplicated list of offsets.
There are currently 99 unique VariantOffsetsWithMetazoneMembershipKind, so storing the index as a u8 is plenty enough.
Implementations
Sourceimpl TimezonePeriods<'_>
impl TimezonePeriods<'_>
Sourcepub fn get(
&self,
time_zone_id: TimeZone,
timestamp: ZoneNameTimestamp,
) -> Option<(VariantOffsets, Option<MetazoneInfo>)>
pub fn get( &self, time_zone_id: TimeZone, timestamp: ZoneNameTimestamp, ) -> Option<(VariantOffsets, Option<MetazoneInfo>)>
Gets the information for a time zone at at timestamp
If the timezone is in a metazone, returns the metazone ID as well as the offsets that the metazone’s golden zone currently uses.
fn find_period( &self, idx: usize, timestamp: ZoneNameTimestamp, ) -> Option<(u8, NichedOption<MetazoneId, 1>)>