MetazoneId

Type Alias MetazoneId 

pub type MetazoneId = NonZeroU8;
Metazone ID in a compact format

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Aliased Type

#[repr(transparent)]
pub struct MetazoneId(/* private fields */);